%%%%%%%%%%% Initialization file %%%
% The below script assembles the relevant dataset information in the opts struct. 
% You need to change this script to match the information of your dataset.
%
% two opts-files have been added as an example
% 1. load('opts_GEHLER.mat') shows my settings on the GEHLER SHI data set
% 2. load('opts_SFU.mat') shows my settings on the outdoor SFU data set 
% (does not contain a mask variable. I used : [yy xx]=ndgrid(1:240,1:360); mask_ball=yy>120 & xx>220; )
%
%%%%

clear opts
 
opts.imgpath    = '/home/joost/images/cc_gehler/gehler_shi/';                       % image location
opts.img_names  = textread('/home/joost/images/cc_gehler/image_names.txt','%s');    % the image names

opts.datainfo   = '/home/joost/data/cc_arjan/NTSC_SHI/';                            % location with illuminant and coordinates ball/macbeth 
opts.datapath   = '/home/joost/data/cc_arjan/NTSC_SHI/test/';                       % location to save results
opts.gamma      = 1;                                                                % gamma data set

% the mask is a squared area containing the object used for color calibration (maxcbeth color checker or grey ball)
% the mask would be constant for the SFU.dataset
opts.mask       = getfield(load(sprintf('%s/macbethsquare.mat',opts.datainfo)),'macbeth_coord');        

% get and normalize illuminants
opts.illuminants=getfield(load('/home/joost/data/cc_arjan/NTSC_SHI/groundtruth_funt.mat'),'real_ills_funt');    % illuminants 
opts.illuminants=opts.illuminants./(sqrt(sum(opts.illuminants.^2,2)*ones(1,3)));                                % L2 nomarlized illuminants    

opts.splits=getfield(load(sprintf('%s/testsets.mat',opts.datainfo)),'testsets');    % splits for training and testing (vector of length nImg, indicating for each image its split-id)

opts.nSplits=max(opts.splits);                                                      % number of splits
opts.nImg=size(opts.splits,1);                                                      % number of images in data set

display(opts);